@@ -200,7 +200,7 @@ void LXQtModuleManager::startWm(LXQt::Settings *settings)
     }
 
     mWmProcess->start(mWindowManager, QStringList());
-    
+
     // other autostart apps will be handled after the WM becomes available
 
     // Wait until the WM loads
@@ -273,7 +273,7 @@ void LXQtModuleManager::startConfUpdate()
     startProcess(desktop);
 }
 
-void LXQtModuleManager::restartModules(int /*exitCode*/, QProcess::ExitStatus exitStatus)
+void LXQtModuleManager::restartModules(int exitCode, QProcess::ExitStatus exitStatus)
 {
     LXQtModule* proc = qobject_cast<LXQtModule*>(sender());
     if (nullptr == proc) {
@@ -287,8 +287,10 @@ void LXQtModuleManager::restartModules(int /*exitCode*/, QProcess::ExitStatus ex
         switch (exitStatus)
         {
             case QProcess::NormalExit:
-                qCDebug(SESSION) << "Process" << procName << "(" << proc << ") exited correctly.";
-                break;
+                qCDebug(SESSION) << "Process" << procName << "(" << proc << ") exited with code" << exitCode;
+                if (exitCode == 0)
+                    break;
+                // Falls through.
             case QProcess::CrashExit:
             {
                 qCDebug(SESSION) << "Process" << procName << "(" << proc << ") has to be restarted";
